@@ -45,6 +45,3 @@ command_suite = (
         )
     ]
 )
-
-from datalad import setup_package
-from datalad import teardown_package
