@@ -10,7 +10,7 @@ from datalad.interface.base import build_doc
 from datalad.support.param import Parameter
 from datalad.distribution.dataset import datasetmethod
 from datalad.distribution.dataset import require_dataset
-from datalad.interface.utils import eval_results
+from datalad.interface.base import eval_results
 
 from datalad.interface.results import get_status_dict
 from datalad.core.local.run import (
@@ -100,10 +100,10 @@ class ContainersRun(Interface):
 
             # Temporary kludge to give a more helpful message
             if callspec.startswith("["):
-                import simplejson
+                import json
                 try:
-                    simplejson.loads(callspec)
-                except simplejson.errors.JSONDecodeError:
+                    json.loads(callspec)
+                except json.JSONDecodeError:
                     pass  # Never mind, false positive.
                 else:
                     raise ValueError(
